.. _spkg_xindy:

xindy: a general-purpose index processor
==================================================

Description
-----------

This dummy package represents xindy: xindy was developed after an impasse had been encountered in the attempt to complete internationalisation of makeindex. Xindy can be used to process indexes for documents marked up using (LA)TEX, Nroff family and SGML-based languages. Xindy is highly configurable, both in markup terms and in terms of the collating order of the text being processed.

We do not have an SPKG for it. The purpose of this dummy package is to
associate system package lists with it.

License
-------

GNU General Public License version 2.0 (GPLv2)

Upstream Contact
----------------

http://www.xindy.org/

Type
----

optional


Dependencies
------------


Version Information
-------------------


Equivalent System Packages
--------------------------

.. tab:: Debian/Ubuntu

   .. CODE-BLOCK:: bash

       $ sudo apt-get install xindy 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo yum install texlive-xindy 


.. tab:: MacPorts

   .. CODE-BLOCK:: bash

       $ sudo port install xindy 


.. tab:: openSUSE

   .. CODE-BLOCK:: bash

       $ sudo zypper install xindy 



See https://repology.org/project/xindy/versions

If the system package is installed, ``./configure`` will check if it can be used.

